@@ -33,7 +33,7 @@ def cli(ctx, verbose, docker_tag):
     logger=configure_logger('mldock', verbose=verbose)
     logger.info(MLDOCK_LOGO)
     logger.info('Version: ' + CLI_VERSION)
-    ctx.obj = {'verbose': verbose, 'docker_tag': docker_tag, 'helper_library_path':_FILE_DIR_PATH}
+    ctx.obj = {'verbose': verbose, 'docker_tag': docker_tag, 'helper_library_path':_FILE_DIR_PATH, 'logo':MLDOCK_LOGO}
 
 def add_commands(cli):
     cli.add_command(container)
