@@ -6,11 +6,14 @@ import click
 from pathlib import Path
 from future.moves import subprocess
 
+import mldock.api.predict as predict_request
+from mldock.platform_helpers.mldock.utils import \
+    collect_mldock_environment_variables
 from mldock.config.config_manager import \
     ResourceConfigManager, MLDockConfigManager, PackageConfigManager, \
         HyperparameterConfigManager, InputDataConfigManager
 from mldock.api.local import \
-    run_predict, _copy_boilerplate_to_dst, docker_build, \
+    _copy_boilerplate_to_dst, docker_build, \
         _rename_file
 
 from mldock.api.local import \
@@ -19,25 +22,6 @@ from mldock.api.local import \
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
 
-def _format_key_as_mldock_env_var(key, prefix='MLDOCK'):
-    """
-        Formats key as mldock env variable.
-        Replace '\s' and '-', append mldock prefix
-        and lastly transforms to uppercase
-    """
-    if prefix is not None:
-        key = "{}_{}".format(prefix, key)
-    key = key.replace(" ", "_").replace("-", "_")
-    key = key.upper()
-    return key
-
-def _format_dictionary_as_env_vars(obj: dict):
-
-    return {
-        _format_key_as_mldock_env_var(_key): json.dumps(_value)
-        for _key,_value in obj.items()
-    }
-
 @click.group()
 def local():
     """
@@ -45,6 +29,22 @@ def local():
     """
     pass
 
+def pretty_build_logs(line: dict):
+
+    if line is None:
+        return None
+    error = line.get('error', None)
+    errorDetail = line.get('errorDetail', None)
+    if error is not None:
+        logger.error('{}\n{}'.format(error, errorDetail))
+    
+    stream = line.get('stream','')
+
+    if ('Step' in stream) & (':' in stream):
+        logger.info("\n"+stream)
+    else:
+        logger.debug(stream)
+
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option('--no-cache', help='builds container from scratch', is_flag=True)
@@ -82,6 +82,7 @@ def build(obj, dir, no_cache):
         elif image_name.endswith(":latest"):
             raise Exception("\nImage version is not supported at this point. Please remove :latest versioning")
         else:
+            logger.info("\nStarting build...\n")
             docker_build(
                 image_name=image_name,
                 dockerfile_path=dockerfile_path,
@@ -90,6 +91,7 @@ def build(obj, dir, no_cache):
                 requirements_file_path=requirements_file_path,
                 no_cache=no_cache
             )
+            logger.info("\nBuild Complete! ヽ(´▽`)/\n")
     except subprocess.CalledProcessError as e:
         logger.debug(e.output)
         raise
@@ -100,38 +102,22 @@ def build(obj, dir, no_cache):
 @click.command()
 @click.option('--payload', default=None, help='path to payload file', required=True)
 @click.option('--content-type', help='format of payload', type=click.Choice(['json', 'csv'], case_sensitive=False))
-@click.option('--host', help='host url at which model is served', type=str, default='http://127.0.0.1:8080')
-@click.pass_obj
-def predict(obj, payload, content_type, host):
+@click.option('--host', help='host url at which model is served', type=str, default='http://127.0.0.1:8080/invocations')
+def predict( payload, content_type, host):
     """
     Command to run curl predict against an host served on localhost:8080
     """
-    helper_library_path = obj['helper_library_path']
     try:
         if payload is None:
-            logger.info("\nPayload cannot be None")
+            logger.info("\nPayload cannot be None. Please provide path to payload file.")
         else:
-            if content_type == "csv":
-                content_type = 'text/csv'
-                _ = run_predict(
-                    script_path=os.path.join(helper_library_path,'api/predict_csv.sh'),
-                    host=host,
-                    payload=payload,
-                    content_type=content_type
-                )
-            elif content_type == 'json':
-                content_type = 'application/json'
-                _ = run_predict(
-                    script_path=os.path.join(helper_library_path,'api/predict_json.sh'),
-                    host=host,
-                    payload=payload,
-                    content_type=content_type
-                )
-            else:
-                raise TypeError("content-type of payload no supported. Only csv and json are supported at the moment")
-    except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
+            if content_type in ['application/json', 'json']:
+                pretty_output = predict_request.send_json(filepath=payload, host=host)
+            elif content_type in ['text/csv', 'csv']:
+                pretty_output = predict_request.send_csv(filepath=payload, host=host)
+
+            logger.info(pretty_output)
+            logger.info("\nPrediction Complete! ヽ(´▽`)/")
     except Exception as e:
         logger.error("{}".format(e))
         sys.exit(-1)
@@ -158,15 +144,13 @@ def train(obj, dir, tag, stage):
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
     helper_library_path = obj['helper_library_path']
-    hyperparameters_env_var = _format_dictionary_as_env_vars(
-        {'hyperparameters': mldock_config.get('hyperparameters', {})}
-    )
-    project_env_vars = _format_dictionary_as_env_vars(mldock_config.get('environment', {}))
-    env_vars={
-        'stage': stage,
-        **hyperparameters_env_var,
+
+    project_env_vars = mldock_config.get('environment', {})
+    env_vars = collect_mldock_environment_variables(
+        stage=stage,
+        hyperparameters=mldock_config.get('hyperparameters', {}),
         **project_env_vars
-    }
+    )
     try:
         if platform == "sagemaker":
             train_model(
@@ -231,15 +215,13 @@ def deploy(obj, dir, tag, port, stage):
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
     helper_library_path = obj['helper_library_path']
-    hyperparameters_env_var = _format_dictionary_as_env_vars(
-        {'hyperparameters': mldock_config.get('hyperparameters', {})}
-    )
-    project_env_vars = _format_dictionary_as_env_vars(mldock_config.get('environment', {}))
-    env_vars={
-        'stage': stage,
-        **hyperparameters_env_var,
+
+    project_env_vars = mldock_config.get('environment', {})
+    env_vars = collect_mldock_environment_variables(
+        stage=stage,
+        hyperparameters=mldock_config.get('hyperparameters', {}),
         **project_env_vars
-    }
+    )
     try:
         logger.info("Started local deployment at {}...\n".format(port))
         if platform == "sagemaker":
