@@ -458,6 +458,16 @@ class EnvironmentConfigManager(BaseConfigManager):
         except ValueError:
             return False
 
+    @staticmethod
+    def parse_bool(s):
+        """ Returns True is string is a bool. """
+        if s.lower() == 'true':
+            return True
+        elif s.lower() == 'false':
+            return False
+        else:
+            return s
+
     def ask_for_env_vars(self):
         """prompt user for hyperparameters
         """
@@ -472,7 +482,10 @@ class EnvironmentConfigManager(BaseConfigManager):
                 break
             elif "=" in name_value_pair and not name_value_pair == "name=value":
                 name, value = name_value_pair.split("=",1)
-                if value.isdigit():
+                value = self.parse_bool(value)
+                if isinstance(value, bool):
+                    pass
+                elif value.isdigit():
                     value = int(value)
                 elif self.is_float(value):
                     value = float(value)
@@ -484,11 +497,6 @@ class EnvironmentConfigManager(BaseConfigManager):
 class InputDataConfigManager(BaseConfigManager):
     """InputData Config Manager for sagify
     """
-    # attribute_config = { 
-    #         "TrainingInputMode": "File",
-    #         "S3DistributionType": "FullyReplicated",
-    #         "RecordWrapperType": "None"
-    # }
     def __init__(self, config: dict):
         self.config = config
 
@@ -515,20 +523,3 @@ class InputDataConfigManager(BaseConfigManager):
                 })
             else:
                 logger.warning("Expected format as channel/filename. Skipping")
-
-    # def ask_for_input_data_channels(self):
-    #     """prompt users for input data channels
-    #     """
-    #     while True:
-    #         channel = click.prompt(
-    #             text="Add a data channel. (Expects name). Hit enter to continue.",
-    #             default="NULL",
-    #             show_default=False
-    #         )
-    #         if channel == "NULL":
-    #             break
-    #         else:
-    #             logger.info("Adding {} channel".format(channel))
-    #             self.config.update({
-    #                 'channel': channel
-    #             })
