@@ -29,6 +29,12 @@ def transformation():
     """Do an inference on a single batch of data. In this sample server, we take data as JSON"""
     if flask.request.content_type == 'application/json':
         data = flask.request.get_json()
+        result = predict_function.predict(data, content_type='json')
+        return flask.Response(response=json.dumps(result), status=200, mimetype='application/json')
+    elif flask.request.content_type == 'text/csv':
+        data = flask.request.data
+        result = predict_function.predict(data, content_type='csv')
+        return flask.Response(response=result, status=200, mimetype='text/csv')
     else:
         return flask.Response(
             response=json.dumps({'message': 'This predictor only supports JSON data'}),
