@@ -9,7 +9,7 @@ import argparse
 import logging
 
 # Bring in Sagemaker Container Environment handling
-from mldock.platform_helpers.sagemaker import environment
+from mldock.platform_helpers.aws.sagemaker import environment
 env = environment.Environment()
 
 def str2bool(arg_value: str) -> bool:
